# A simple text attribute. It is stored in
# a Python unicode string
class PositionAttribute(Attribute):
    def __init__(self, name="position", title="Position", help = _("Enter position using decimal latitude, longitude <br> Or use button to find position using map"), default_value="60,14", mandatory=False, allow_empty=True, size=42):
        Attribute.__init__(self, name, title, help, default_value)
        self._mandatory = mandatory
        self._allow_empty = allow_empty
        self._size = size

    def paint(self, value, hostname):
        if not value:
            return "", ""
        else:
            return "", value

    def is_mandatory(self):
        return self._mandatory

    def render_input(self, value):
        if value == None:
            value = ""
        html.text_input("attr_" + self.name(), value, size = self._size, id="attr_position_textbox")
        html.icon_button("javascript:void(0)", _("Find position using map"), "gmaps",
            onclick="window.open(('positionpicker.html?pos=' + document.getElementById('attr_position_textbox').value),'location picker','width=600,height=500');")

    def from_html_vars(self):
        value = html.var_utf8("attr_" + self.name())
        if value == None:
            value = ""
        return value.strip()

    def validate_input(self):
        value = self.from_html_vars()
        if self._mandatory and not value:
            raise MKUserError("attr_" + self.name(),
                  _("Please specify a value for %s") % self.title())
        if value.strip() == "" and not self._allow_empty:
            raise MKUserError("attr_" + self.name(),
                  _("%s may be missing, if must not be empty if it is set.") % self.title())
        if not re.match("^\d{1,3}(\.\d{1,15})?,?\d{1,3}(\.\d{1,15})?$", value):
            raise MKUserError("attr_" + self.name(),
                  _("%s is not a correct google maps coordinate") % self.title())

    def filter_matches(self, crit, value, hostname):
        if value == None:  # Host does not have this attribute
            value = ""
        return crit.lower() in value.lower()

    def to_nagios(self, value):
        if value:
            return value

    def nagios_name(self):
        return "_POSITION"

declare_host_attribute(PositionAttribute(),
                       show_in_table = False,
                       show_in_folder = False)
